If you use acstools, please cite as:

[![NASA/ADS-ACStools](https://img.shields.io/badge/NASA%2FADS-ACStools-blue)](https://ui.adsabs.harvard.edu/abs/2020ascl.soft11024L/abstract)

#### Other forms of citation

[![ascl:2011.024](https://img.shields.io/badge/ascl-2011.024-blue.svg?colorB=262255)](https://ascl.net/2011.024)

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.7406933.svg)](https://doi.org/10.5281/zenodo.7406933)
